@@ -161,6 +161,7 @@ import ast
 from copy import deepcopy
 import os
 import pathlib
+from pprint import pformat
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 from ae.base import norm_line_sep, norm_name                                    # type: ignore
@@ -169,7 +170,7 @@ from ae.i18n import get_f_string
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.1.29'
+__version__ = '0.1.30'
 
 
 FLOW_PATH_ROOT_ID = 'ROOT'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -295,11 +296,15 @@ class LiszDataMixin(ABC):
     _refreshing_data: bool = False                      #: DEBUG True while running :meth:`~.refresh_all` method
 
     # abstract methods
-    # the gui_app methods are not really abstract (nor callable via super()) but declared here for to hide inspections
+    # the gui_app methods are not really abstract (nor callable via super()) but declared here for proper type checking
     @abstractmethod
     def call_method(self, method: str, *args, **kwargs) -> Any:
         """ call method of this instance (ae.gui_app.MainAppBase method). """
 
+    @abstractmethod
+    def call_method_delayed(self, delay: float, method: str, *args, **kwargs) -> Any:
+        """ call method of this instance delayed (ae.gui_app.MainAppBase method). """
+
     @abstractmethod
     def change_app_state(self, state_name: str, state_value: Any, send_event: bool = True):
         """ add debug sound on each state change/save (ae.gui_app.MainAppBase method). """
@@ -394,15 +399,15 @@ class LiszDataMixin(ABC):
     def current_item_or_node_literal(self) -> str:
         """ return the currently focused/displayed item or node as repr string.
 
-        :return:                repr string of the currently focused item id/node or of the displayed node.
+        :return:                pformat repr string of the currently focused item id/node or of the displayed node.
         """
         flow_id = self.flow_id
         if flow_action(flow_id) != 'focus':
-            lit = repr(self.flow_path_node())
+            lit = pformat(self.flow_path_node())
         else:
             item = self.item_by_id(flow_key(flow_id))
             if 'node' in item:
-                lit = repr(item)
+                lit = pformat(item)
             else:
                 lit = item['id']
         return lit
@@ -1026,6 +1031,7 @@ class LiszDataMixin(ABC):
             snd_name = 'deleted'
             event_kwargs['flow_id'] = id_of_flow('')
             event_kwargs['reset_last_focus_flow_id'] = True
+            event_kwargs['changed_event_name'] = 'refresh_all'
         self.shrink_node_size(extract_node, item_filter=extract_filter, recursive=recursive)
 
         if extract_action in ('copy', 'cut'):
@@ -1033,9 +1039,7 @@ class LiszDataMixin(ABC):
         elif extract_action == 'export':
             self.export_node(flow_path, file_path=event_kwargs.get('export_path', '.'), node=extract_node)
         elif extract_action == 'share':
-            self.call_method('share_node', flow_path, node=extract_node)
-
-        event_kwargs['changed_event_name'] = 'refresh_all'
+            self.call_method_delayed(0.69, 'share_node', flow_path, node=extract_node)
 
         # dismiss prevents dropdown._reposition() weakref-err (refresh_all() recreates attach_to widget)
         # event_kwargs['popups_to_close'][0].attach_to = None  # close() results in weakref-err in container.on_dismiss
